==> haskell-checkers-0.6.0-167-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 checkers
version:              0.6.0
visibility:           public
id:                   checkers-0.6.0-BiWgER1NUu1EGXGlv5lRoH
key:                  checkers-0.6.0-BiWgER1NUu1EGXGlv5lRoH
license:              BSD-3-Clause
copyright:            (c) 2008-2013 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott
stability:            experimental
homepage:             https://github.com/haskell-checkers/checkers
synopsis:             Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.

    &#169; 2008-2013 by Conal Elliott; BSD3 license.

category:             Testing
abi:                  fce5ef17a39c8d98f95abbcde4fb9b52
exposed:              True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils

hidden-modules:       Control.Monad.Extensions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/checkers-0.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/checkers-0.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/checkers-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-checkers
hs-libraries:         HScheckers-0.6.0-BiWgER1NUu1EGXGlv5lRoH
depends:
    QuickCheck-2.14.3-GIUqI8qD1o41rCLRe3Qcl2 array-0.5.4.0
    base-4.17.2.1 random-1.2.1.2-Cz5v09VeJop2IMLe7A0P8g
    semigroupoids-6.0.1-KVoagb3crffLRdR9EQjlIH

haddock-interfaces:   /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html:         /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-checkers-0.6.0-169-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 checkers
version:              0.6.0
visibility:           public
id:                   checkers-0.6.0-7yYDBFqbnEf26cudAfe76K
key:                  checkers-0.6.0-7yYDBFqbnEf26cudAfe76K
license:              BSD-3-Clause
copyright:            (c) 2008-2013 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott
stability:            experimental
homepage:             https://github.com/haskell-checkers/checkers
synopsis:             Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.

    &#169; 2008-2013 by Conal Elliott; BSD3 license.

category:             Testing
abi:                  bb082f0d5ff180844adffc4fe3f3b4f9
exposed:              True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils

hidden-modules:       Control.Monad.Extensions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/checkers-0.6.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/checkers-0.6.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/checkers-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-checkers
hs-libraries:         HScheckers-0.6.0-7yYDBFqbnEf26cudAfe76K
depends:
    QuickCheck-2.14.3-1OQe8vVNhDx8BJsM0dw2LX array-0.5.4.0
    base-4.17.2.1 random-1.2.1.2-8zs3ZWfUMfhHEc0bNUHZYO
    semigroupoids-6.0.1-L1SyrkGv2pGGclnteZiiwF

haddock-interfaces:   /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html:         /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
